Tildes
Description: Tildes is a non-profit community site with no advertising or investors. It respects its users and their privacy, and prioritizes high-quality content and discussions.

- Activity
- Votes
- Comments
- New
- All activity
from

1. # What is the best way to be involved in a forum discussion

   ~tech
   - social media
   Ask (advice)
   I signed onto Reddit six years ago because that was where I could discuss stuff I liked intelligently. Due to social awkwardness and poor conversational skills, I feel like I contribute nothing to...

   I signed onto Reddit six years ago because that was where I could discuss stuff I liked intelligently. Due to social awkwardness and poor conversational skills, I feel like I contribute nothing to the conversation anywhere, on forums or IRL. I even signed up for Stack Exchange, Hacker News, and Ars Techinca for discussion, but they all look like you need a Ph.D. to contribute anything meaningful?

   Am I alone on this? How can I be a productive part of the conversation?

   3 votes

2. # Any fans of British comedy series here?

   ~tv Ask (survey)
   I moderate(d) the Allo Allo subreddit before that site…well, you know. I know the show has many fans, and I want us to all congregate here! I miss feeling like there were others out there. I am...

   I moderate(d) the Allo Allo subreddit before that site…well, you know.

   I know the show has many fans, and I want us to all congregate here! I miss feeling like there were others out there.

   I am guessing those people haven't ended up here, so I thought I should broaden it to include British comedy series in general. What's your favorite? Why?

   4 votes

3. # Share your recent Platinum, 100% or 1000G you have achieved

   ~games Ask (survey)
   I recently earned the platinum for Riders Republic, its a fun game, takes around 40-45 hours to get the plat and outside of tricks battle mode its not too difficult, but I enjoy playing tricks...

   I recently earned the platinum for Riders Republic, its a fun game, takes around 40-45 hours to get the plat and outside of tricks battle mode its not too difficult, but I enjoy playing tricks battles.
   I haven't moved on from the game after getting the plat though cause im levelling up to get elite level gear to win 64 player mass races, I got first place for the first time yesterday and consistently get podium finish

   3 votes

4. # Anyone into painting (more specifically watercolors?)

   ~hobbies Ask (survey)
   Just curious. I've been trying to understand watercolors better. What I love about watercolors: so much expression, so much freedom. It also seems like a uniquely frustrating medium; understanding...

   Just curious. I've been trying to understand watercolors better. What I love about watercolors: so much expression, so much freedom. It also seems like a uniquely frustrating medium; understanding how much water is needed, how water reacts with certain papers, different types of brushes, etc. (I should mention it's the only painting I do, so maybe this stuff isn't unique to watercolor.)

   Curious if there's any other watercolor enthusiasts here. Care to share your experiences, or tips for a novice?

   1 vote

5. # Interview with an EMacs Enthusiast in 2023 [Colorized]

   ~comp Video 8:50, published Jun 10 2023
   1 vote

6. # Is it even worthwhile to turn off ad personalization or location tracking for services/apps?

   ~tech Ask (advice)
   So, I’m moving to a new phone and revisiting a lot of accounts, apps, and settings. When it comes to things like location history or ad personalization or whatever, is it even worthwhile to turn...

   So, I’m moving to a new phone and revisiting a lot of accounts, apps, and settings.

   When it comes to things like location history or ad personalization or whatever, is it even worthwhile to turn it off? Am I really supposed to believe that because I have some toggle off that Google suddenly doesn’t track where I drive on Maps? Like if they are going to be tracking me, which I assume they are, I might as well be able to see it to rather than have it exist in the aether somewhere where the info is attributed to me but not viewable in the UI.

   Even with ads, I know shadow profiles are a thing, and that they definitely have data beyond what they show in the UI, so might as well opt in there too right? Plus, the non-targeted ads I get are basically porn-tier ads or stuff for gay men.

   What should I do here? Move into the woods? Feels like I can’t win.

   2 votes

7. # Thoughts on LGBT memes and cliches

   ~lgbt
   - transgender
   Ask
   By this i mean things like blahaj, programmer socks, etc. Personally i think theyre kinda funny and i myself have gotten my own blahaj as a way to show my "trans license" but i was wondering how...

   By this i mean things like blahaj, programmer socks, etc. Personally i think theyre kinda funny and i myself have gotten my own blahaj as a way to show my "trans license" but i was wondering how other people might feel about them. Perhaps some people think theyre overdone or they just dont agree with them.

   3 votes

8. # Finland is on the verge of becoming the first nation to bury spent nuclear fuel rods deep underground for the long term

   ~enviro
   - energy
   Article 2756 words
   5 votes

9. # Kanopy - Free movie streaming

   ~movies Link
   12 votes

10. # Do you go make active efforts to find new music? If so - how?

    ~music Ask (recommendations)
    TL;DR Send me new music (please). That off-the-wall shit that you wouldn't recommend to anyone else. I enjoy finding and sharing new music. The more obscure and unknown the better because the more...

    TL;DR Send me new music (please). That off-the-wall shit that you wouldn't recommend to anyone else. I enjoy finding and sharing new music. The more obscure and unknown the better because the more likely it'll actually be new. Also some tips on finding new music yourself if you've been wanting to expand your horizons.

    I went through a period of musical stagnation from around 2008-2017 where I rarely found or enjoyed any new music. I mostly listened to the same dozen or so artists on repeat and even that was mostly the same songs and genres. After graduating from school there wasn't anyone to "pass the aux cable" to and so my music discovery went down the drain.

    Starting in 2018 I decided enough was enough of that. I absolutely love music and even if I don't vibe with every aspect of a song I can usually find an aspect or quality of a song that I enjoy.

    I'll admit I'm a bit of a hipster in that I love finding small artists/bands but the reason for this is I absolutely love introducing people to new music and the best way to do that is to get off the Top100 Charts. I also try and get away from "underrated" artists who are actually quite well known among people who love that specific genre of music. They're not really "mainstream" but they're still "well known". By that I mean artists like Aesop Rock if you're into rap or Aurora if you're into SynthPop - if your "underrated"/"underground" artist has a YouTube video with >5m views or shows up in a "Top 20 Underrated Artists in <genre>" listicle on the 1st page of Google results they're well known - just not mainstream. [0]

    Some tips for exploring (and how I personally explore):

    - Pay attention to labels - at least for the smaller/indie labels that stick to a particular genre/feel/aesthetic. One of my favorite JP rap labels is "Low High Who?" and while I'm not a fan of every single artist they have a lot of talent on their roster and they have a pretty consistent aesthetic to their songs and MV's.
    - Ever find a new song from a new artist that you love so you check out their other songs and... they're just... bad? Or not your style? Check out who produced or mixed the song. Chances are actually pretty high that the one song you like is the only song that was produced by that producer with a different producer working on all the other tracks! Check out other work by the Producer and you might find a band where they produced an entire album instead of being a guest producer on a single song of one album.
    - Search for local talent! Even if you don't actually go/attend any shows a lot of those bands will have either a YouTube or Bandcamp profile if you look for them.
    - YouTube Algorithm will occasionally show me some banger new music with <4,000 views. If I see an interesting thumbnail and especially if I notice it has almost no views but is showing up in my recs I'll give it a listen real quick.
    - Every Noise at Once and pick a genre that makes me say "Huh - I don't know what that genre even sounds like." Time to go listen to whatever the hell "gymcore" is meant to be.
    - Asking people to really dig deep with their recs. :) Give me something off the wall! Have that favorite song that you never share because you don't think anyone else has the same music taste as you or are afraid of being judged for liking some weird shit? Sweet! Share it. I want to hear it. I don't care what genre it is - send me a link and I'll listen to it.

    Lately I've been trying to expand my horizons even more because in 2022 I only added a whopping 1 new song to my yearly "new music" playlist compared to 26 in 2021 and 45 in 2020. 2023 has been looking better with 17 new songs but I really want to break my 2020 record. These playlists are "new music I enjoyed" and the music doesn't need to be "new" - only new to me. One of the first new additions was Merk & Kremont - Sad Story (Out Of Luck) (playlist link if you want to see the other 16 songs from this year).

    [0] That isn't to say I don't also listen to and enjoy mainstream or "underrated" artists. Aesop Rock is hands down my favorite American/English-speaking rapper by a pretty large margin and I'm a fan of Aurora's work too. But they're also some of the first names dropped whenever you're asking for an <underrated artists> in <genre>.

    16 votes

Next